@@ -2,7 +2,7 @@
 
    cd-drive.c: easy to use cd burner software
 
-   Copyright (C) 2002 Red Hat, Inc.
+   Copyright (C) 2002-2004 Red Hat, Inc.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -1420,6 +1420,26 @@ cd_drive_get_file_image (void)
 	return cdrom;
 }
 
+/* This is used for testing different configurations */
+#if 0
+static GList*
+test_cdroms (void)
+{
+	GList *list = NULL;
+	CDDrive *drive = g_new0 (CDDrive, 1);
+	drive->type = CDDRIVE_TYPE_CD_DRIVE | CDDRIVE_TYPE_DVD_DRIVE;
+	drive->display_name = g_strdup ("HL-DT-STDVD-ROM");
+	drive->device = g_strdup ("/dev/hdc");
+	list = g_list_append (list, drive);
+	drive = g_new0 (CDDrive, 1);
+	drive->type = CDDRIVE_TYPE_CD_DRIVE | CDDRIVE_TYPE_DVD_DRIVE | CDDRIVE_TYPE_CD_RECORDER;
+	drive->display_name = g_strdup ("_NEC DVD_RW ND-2500A");
+	drive->device = g_strdup ("/dev/hdd");
+	list = g_list_append (list, drive);
+	return list;
+}
+#endif
+
 GList *
 scan_for_cdroms (gboolean recorder_only, gboolean add_image)
 {
