@@ -117,6 +117,7 @@ int get_dvd_r_rw_profile (const char *name)
       /* fprintf(stderr,"GET CONFIGURATION failed with "
 		      "SK=%xh/ASC=%02xh/ASCQ=%02xh\n",
 		      sense[2]&0xF,sense[12],sense[13]); */
+      delete list;
       goto bail;
     }
 
@@ -124,6 +125,7 @@ int get_dvd_r_rw_profile (const char *name)
     {
       /* fprintf(stderr, "GET CONFIGURATION with len %d, and list[11] %d\n",
                          len, list[11]); */
+      delete list;
       goto bail;
     }
 
@@ -146,6 +148,7 @@ int get_dvd_r_rw_profile (const char *name)
           retval = 1;
       }
     }
+    delete list;
   }
 
 bail:
@@ -209,6 +212,51 @@ bail:
 
 }
 
+extern "C"
+int get_disc_status (int fd, int *empty, int *is_rewritable)
+{
+  Scsi_Command cmd(fd);
+  int retval = -1;
+  unsigned char page[32];
+  unsigned char *sense=cmd.sense();
+  int i;
+
+  *empty = 0;
+  *is_rewritable = 0;
+
+  /* For valgrind */
+  memset (&page, 0, sizeof (page));
+
+  cmd[0]=0x51;
+  cmd[8]=32;
+  cmd[9]=0;
+  if (cmd.transport(READ,page,32))
+  {     
+    if (((sense[2]&0xF) == 2) && 
+	(sense[12] == 0x3a)) {
+      /* MEDIUM NOT PRESENT */
+      *empty = 1;
+      return 0;
+    }
+
+    /*if (sense[0]==0) perror("Unable to ioctl");
+    else             fprintf(stderr,"READ DISC INFORMATION failed with "
+			     "SK=%xh/ASC=%02xh/ASCQ=%02xh\n",
+			     sense[2]&0xF,sense[12],sense[13]); */
+    goto bail;
+  }
+  
+  *is_rewritable = (page[2] & 0x10) != 0;
+
+  return 0;
+
+bail:
+
+  return retval;
+
+}
+
+
 extern "C"
 int get_disc_size_cd (int fd)
 {
@@ -451,7 +499,10 @@ int get_read_write_speed (int fd, int *read_speed, int *write_speed)
     *write_speed = p[28] << 8 | p[29];
   }
 
-  *read_speed = p[8] << 8 | p[9];
+  if (len >= hlen+9)
+    *read_speed = p[8] << 8 | p[9];
+  else
+    *read_speed = 0;
 
   return 0;
 
