@@ -648,12 +648,15 @@ burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean
 				res = make_iso (filename, label,
 						TRUE, TRUE, debug);
 			}
+		}
 
-			if (!res) {
-				/* User cancelled or we had an error. */
-				cancel = CANCEL_NONE;
-				goto out;
+		if (res != RESULT_FINISHED) {
+			/* User cancelled or we had an error. */
+			if (res == RESULT_ERROR) {
+				ncb_hig_show_error_dialog (_("File image creation failed"), _("Incorrectly named files were to be added to the CD"), NULL);
 			}
+			cancel = CANCEL_NONE;
+			goto out;
 		}
 	}
 
@@ -715,18 +718,19 @@ burn_cd (const CDDrive *rec, const char *source_iso, const char *label, gboolean
 			unlink (filename);
 		}
 
+		cancel = CANCEL_NONE;
+
 		if (res == RESULT_FINISHED) {
+			g_object_unref (cdrecorder);
 			cd_progress_set_text (_("Complete"));
 			setup_close_button ();
 			gtk_main ();
 		} else if (res != RESULT_CANCEL) {
 			show_error_message (cdrecorder);
+			g_object_unref (cdrecorder);
 		}
-
-		cancel = CANCEL_NONE;
-		g_object_unref (cdrecorder);
 	}
-	
+
  out:
 	g_free (filename);
 	g_list_foreach (tracks, (GFunc)cd_recorder_track_free, NULL);
